Package: baseverse
Title: Modern Base-R Functions
Version: 0.1.4
Authors@R: 
    person(given = 'Yea-Hung', family = 'Chen', 
       email = 'yea-hung.chen@ucsf.edu', role = c('aut','cre'))
Description: Includes modern base-R functions. Functions beginning with p_ are wrapper functions for existing base-R functions, supporting native piping. Other functions are wrapper functions for core base-R features, including bracket notation and dollar-sign notation. base_match() and base_when() mimic case_match() and case_when() from 'dplyr' but return a factor by default with levels ordered according to user input. et() mimics count() from 'dplyr'. 
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.2
LazyData: true
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-04-28 21:04:46 UTC; yea-hung
Author: Yea-Hung Chen [aut, cre]
Maintainer: Yea-Hung Chen <yea-hung.chen@ucsf.edu>
Depends: R (>= 4.1.0)
Repository: CRAN
Date/Publication: 2026-04-28 21:30:02 UTC
Built: R 4.5.2; ; 2026-05-01 17:02:53 UTC; unix

# Generated by roxygen2: do not edit by hand

export(bang)
export(base_match)
export(base_when)
export(bracket)
export(dollar)
export(et)
export(not)
export(p_cor)
export(p_glm)
export(p_lm)
export(p_t.test)
export(p_table)
export(p_wilcox.test)

# Overview

*baseverse* is a collection of functions intended to support the continued use of base R in a modern era. There are two main types of functions included in the package:

- **wrapper functions** to existing base-R functions: These begin with `p_` and support native piping. For example, `p_lm()` is a wrapper to `lm()` supporting native piping.
- **functions that mimic tidyverse** functions: These include `base_match()` and `base_when()` (see section below).

# Installation

The package is now available on CRAN! 🥳 

To install the GitHub version instead (which may be more recent than the CRAN version), first install *remotes* if you don't already have it:

```r
install.packages('remotes')
```

Then, install the *baseverse* package using `install_github()`:

```r
remotes::install_github('yea-hung/baseverse')
```

# Suggestions and future directions

Please don't hesitate to contribute if you have ideas for expanding this!

# `base_match()` and `base_when()`

## Motivation

As [mentioned elsewhere](https://github.com/tidyverse/funs/issues/72), `case_match()` and `case_when()` do not return a factor. A [typical tidyverse solution](https://stackoverflow.com/questions/49572416/r-convert-to-factor-with-order-of-levels-same-with-case-when) for getting a factor out of `case_match()` with the levels in a desired order is something like this:
 
```r
nhanes<-nhanes %>%
  mutate(
    country=factor(
      case_match(dmdborn4,1 ~ 'USA',2 ~ 'Other'),
      levels=c('USA','Other')
    )
  )
```

In this sort of solution, we have to type the level labels twice. The first occurrence defines the label-level mapping, while the second occurrence defines the order of the levels. I think this is inefficient.

Compare the above with the following base-R solution:

```r
dmdborn4_codebook<-c('USA'=1,'Other'=2)
nhanes$country<-factor(nhanes$dmdborn4,levels=dmdborn4_codebook,
                       labels=names(dmdborn4_codebook))
```

Here, we only have to type the level labels once: that one occurrence defines both the label-level mapping and the order of the levels.

My starting principle in writing `base_match()` and `base_when()` is that one should only have to type the level labels once.

## Examples

`base_match()` using native piping:

```r
nhanes<-nhanes |>
  transform(country=base_match(dmdborn4,'USA'=1,'Other'=2))
```

`base_when()` using native piping:

```r
nhanes<-nhanes |>
  transform(
    cholesterol=base_when(
      'Desirable' = (lbxtc<200),
      'Borderline high' = (lbxtc>=200)&(lbxtc<240),
      'High' = (lbxtc>=240)
    )
  )
```
## Warning

Despite the cute name, `base_when()` does not exactly mimic `case_when()`, and I do not intend it to. A key difference is `base_when()` will evaluate all conditions defined in `conditions` whereas `case_when()` will, for each position, stop when a condition is met.

#' Uses the logical not
#' 
#' A wrapper function for `!`. This is the same thing as `bang()`.
#'
#' @param x a logical object
#'
#' @returns a logical object
#' @export
#'
#' @examples
#' # load the data
#' data(nhanes)
#' 
#' # check whether values of smq020 are not missing
#' nhanes$smq020 |> is.na() |> not()
#' 
#' # check whether values of smq020 are not missing
#' nhanes |> dollar(smq020) |> is.na() |> not()
not<-function(x){ !x }

#' Fits generalized linear models, with support for piping
#' 
#' A wrapper function for `glm()`, with the `data` argument listed first to support piping.
#'
#' @param data the data
#' @param formula the formula
#' @param ... additional arguments passed to [stats::glm()].
#'
#' @returns a `glm` object
#' @export
#'
#' @examples
#' # load the data
#' data(nhanes)
#'
#' # define asthma
#' nhanes<-nhanes |> transform(
#'   asthma=base_match(mcq010,'No'=2,'History of asthma'=1)
#' )
#'
#' # define smoking
#' nhanes<-nhanes |> transform(
#'   smoking=base_match(smq020,'No'=2,'History of smoking'=1)
#' )
#' 
#' # fit a model
#' my_model<-nhanes |> p_glm(asthma~smoking,family=binomial(link='logit'))
#' 
#' # obtain model details
#' my_model |> summary()
#' 
#' # obtain confidence interval
#' my_model |> confint() |> exp()
p_glm<-function(data,formula,...) {
  stats::glm(formula=formula,data=data,...)
}

#' Defines factors using value-label mapping
#'
#' A base-R approximation of `case_match()` from 'dplyr'. Unlike `case_match()`, `base_when()` returns a factor. The levels will be ordered according to the order included in `...` (see below).
#' @param original_variable the original variable
#' @param ... the codebook, specified as a named vector, with each element in `'label'=value` format, with the levels listed in the desired order
#' @param as_factor logical, controlling whether the function should return a factor
#' @param string_for_na string value that will be converted to NA
#'
#' @returns a factor
#' @export
#'
#' @examples
#' # load data
#' data(nhanes)
#' 
#' # define country
#' nhanes<-nhanes |> transform(
#'   country=base_match(dmdborn4,'USA'=1,'Other'=2)
#' )
base_match<-function(original_variable,...,as_factor=TRUE,string_for_na=''){

  # define the codebook
  codebook<-list(...)
  codebook<-unlist(codebook)

  # define the new variable
  new_variable<-factor(original_variable,codebook,names(codebook))
  
  # convert the variable to a character object (not default behavior)
  if(!as_factor){
    new_variable<-as.character(new_variable)
    new_variable[is.na(new_variable)]<-string_for_na
  }

  # return the object
  new_variable

}

#' National Health and Nutrition Examination Survey data
#'
#' A subset of data from the National Health and Nutrition Examination Survey
#'
#' @format ## `nhanes`
#' A data frame with 8,153 rows and 3 columns:
#' \describe{
#'   \item{seqn}{a unique identifier}
#'   \item{riagendr}{gender}
#'   \item{ridageyr}{age}
#'   \item{dmqmiliz}{military status}
#'   \item{dmdborn4}{country of birth}
#'   \item{lbxtc}{total cholesterol}
#'   \item{bpxosy1}{systolic blood pressure}
#'   \item{bpxosy2}{systolic blood pressure}
#'   \item{bpxodi1}{diastolic blood pressure}
#'   \item{bpxodi2}{diastolic blood pressure}
#'   \item{mcq010}{asthma}
#'   \item{smq020}{smoking status}
#' }
#' @source <https://wwwn.cdc.gov/nchs/nhanes/continuousnhanes/default.aspx?Cycle=2021-2023>
"nhanes"

#' Defines factors using logical objects
#'
#' A base-R approximation of `case_when()` from 'dplyr'. Unlike `case_when()`, `base_when()` returns a factor. The levels will be ordered according to the order included in `...` (see below).
#' @param ... conditions for defining the replacement values, specified as a named list, with each element in `'label'=logical_vector` format, with the levels listed in the desired order
#' @param as_factor logical, controlling whether the function should return a factor
#' @param string_for_na string value that will be converted to NA
#'
#' @returns a factor
#' @export
#'
#' @examples
#' # load data
#' data(nhanes)
#' 
#' # define cholesterol
#' nhanes<-nhanes |>
#'   transform(
#'     cholesterol=base_when(
#'       'Desirable' = (lbxtc<200),
#'       'Borderline high' = (lbxtc>=200)&(lbxtc<240),
#'       'High' = (lbxtc>=240)
#'     )
#'   )
base_when<-function(...,as_factor=TRUE,string_for_na=''){

  # define the conditions
  conditions<-list(...)

  # define the new variable
  new_variable<-rep(string_for_na,length(conditions[[1]]))

  # define the variable's groups
  for(position in 1:length(conditions)){
    new_variable[conditions[[position]]]<-names(conditions)[position]
  }
  
  # convert the variable to a factor (default behavior)
  if(as_factor){
    new_variable<-factor(new_variable,levels=unique(names(conditions)))  
  }

  # return the object
  new_variable

}

#' Selects a portion of a data object using dollar-sign selection
#'
#' A wrapper function for dollar-sign notation.
#' @param data_object the data object
#' @param variable_name the variable name or element name
#'
#' @returns a portion of the data object
#' @export
#'
#' @examples
#' # load data
#' data(nhanes)
#' 
#' # summarize lbxtc
#' nhanes |> dollar(lbxtc) |> summary()
dollar<-function(data_object,variable_name){

  variable_string<-deparse(substitute(variable_name))
  if(is.null(dim(data_object))){
    data_object |> (\(x) x[[variable_string]])()
  } else {
    if(length(dim(data_object))==1){
      data_object |> (\(x) x[variable_string])()  
    }
    if(length(dim(data_object))==2){
      data_object |> (\(x) x[,variable_string])()  
    }
  }

}

#' Tables variables, with support for piping
#' 
#' A wrapper function for `table()`, with support for piping.
#'
#' @param data the data
#' @param x one variable
#' @param y another variable
#' @param ... additional arguments passed to [table()].
#'
#' @returns a `table` object
#' @export
#'
#' @examples
#' # load the data
#' data(nhanes)
#' 
#' # define smoking
#' nhanes<-nhanes |> transform(
#'   smoking=base_match(smq020,'No'=2,'History of smoking'=1)
#' )
#' 
#' # define asthma
#' nhanes<-nhanes |> transform(
#'   asthma=base_match(mcq010,'Asthma'=1,'No'=2)
#' )
#' 
#' # table smoking
#' nhanes |> p_table(smoking)
#' 
#' # table smoking and asthma
#' nhanes |> p_table(smoking,asthma)
p_table<-function(data,x,y=NULL,...){
  x_string<-deparse(substitute(x))
  y_string<-deparse(substitute(y))
  if(y_string=='NULL'){
    table(data[,x_string],...)
  } else {
    table(data[,x_string],data[,y_string],...)
  }
}

#' Subsets a data using bracket notation
#' 
#' A wrapper function for bracket notation. The function only allows one index; for two-dimensional objects, the index is used on the columns.
#'
#' @param data_object a data object
#' @param index a character, logical, or numeric vector
#'
#' @returns a subset of the data
#' @export
#'
#' @examples
#' # load package
#' data(nhanes)
#' 
#' # look at the first few values of dmdborn4
#' nhanes |> bracket('dmdborn4') |> head()
bracket<-function(data_object,index){
  
  if(length(dim(data_object))==1){
    data_object[index]
  }
  if(length(dim(data_object))==2){
    data_object[,index]
  }
  
}

#' Conducts Wilcoxon rank-sum tests, with support for piping
#' 
#' A wrapper function for `wilcox.test()`, with the `data` argument listed first to support piping.
#'
#' @param data the data
#' @param x one of two variables
#' @param y one of two variables
#' @param formula a formula
#' @param ... additional arguments passed to [stats::wilcox.test()].
#'
#' @returns an `htest` object
#' @export
#'
#' @examples
#' # load the data
#' data(nhanes)
#' 
#' # define smoking
#' nhanes<-nhanes |> transform(
#'   smoking=base_match(smq020,'No'=2,'History of smoking'=1)
#' )
#' 
#' # conduct a one-sample wilcoxon test
#' nhanes |> p_wilcox.test(bpxosy1)
#' 
#' # conduct a two-sample wilcoxon test, using formula notation
#' nhanes |> p_wilcox.test(bpxosy1~smoking)
#' 
#' # conduct a two-sample wilcoxon test, using formula notation
#' nhanes |> p_wilcox.test(formula=bpxosy1~smoking)
#'
#' # conduct a paired wilcoxon test, using x and y
#' nhanes |> p_wilcox.test(bpxosy1,bpxosy2,paired=TRUE)
p_wilcox.test<-function(data,x=NULL,y=NULL,formula=NULL,...) {
  x_string<-deparse(substitute(x))
  y_string<-deparse(substitute(y))
  formula_string<-deparse(substitute(formula))
  if(grepl('~',x_string)&(y_string=='NULL')&(formula_string=='NULL')){
    wilcox_test<-stats::wilcox.test(formula=x,data=data,...)
  } 
  if(!grepl('~',x_string)&(y_string=='NULL')&(formula_string=='NULL')){
    wilcox_test<-stats::wilcox.test(data[,x_string],...)
    wilcox_test$data.name<-x_string
  }
  if(!grepl('~',x_string)&(y_string!='NULL')&(formula_string=='NULL')){
    wilcox_test<-stats::wilcox.test(data[,x_string],data[,y_string],...)
    wilcox_test$data.name<-paste(x_string,'and',y_string)
  }
  if(formula_string!='NULL'){
    wilcox_test<-stats::wilcox.test(formula=formula,data=data,...)
  }
  wilcox_test
}

#' Fits linear models, with support for piping
#' 
#' A wrapper function for `lm()`, with the `data` argument listed first to support native piping.
#'
#' @param data the data
#' @param formula the formula
#' @param ... additional arguments passed to [stats::lm()].
#'
#' @returns an `lm` object
#' @export
#'
#' @examples
#' # load the data
#' data(nhanes)
#'
#' # define country
#' nhanes<-nhanes |> transform(
#'   country=base_match(dmdborn4,'USA'=1,'Other'=2)
#' )
#'
#' # fit a model
#' my_model<-nhanes |> p_lm(bpxosy1~country)
#' 
#' # obtain model details
#' my_model |> summary()
#' 
#' # obtain confidence interval
#' my_model |> confint()
p_lm<-function(data,formula,...) {
  stats::lm(formula=formula,data=data,...)
}

#' Finds correlation coefficients, with support for piping
#' 
#' A wrapper function for `cor()`, with support for piping.
#'
#' @param data the data
#' @param x one of the two variables
#' @param y one of the two variables
#' @param ... additional arguments passed to [stats::cor()].
#'
#' @returns a numeric object
#' @export
#'
#' @examples
#' # load the data
#' data(nhanes)
#' 
#' # get correlation coefficient for systolic and diastolic
#' nhanes |> p_cor(bpxosy1,bpxodi1,use='complete.obs')
p_cor<-function(data,x,y,...){
  x_string<-deparse(substitute(x))
  y_string<-deparse(substitute(y))
  stats::cor(data[,x_string],data[,y_string],...)
}

#' Tables variables
#'
#' Creates a table for a variable, mimicking `count()` from 'dplyr'. ET stands for exploratory table or easy table.
#' @param data_frame the data.frame
#' @param variable_name the variable name
#'
#' @returns a data frame
#' @export
#'
#' @examples
#' # load data
#' data(nhanes)
#' 
#' # define country
#' nhanes<-nhanes |> transform(
#'   country=base_match(dmdborn4,'USA'=1,'Other'=2)
#' )
#' 
#' # examine variable, with native piping
#' nhanes |> et(country)
#' 
#' # examine variable, with dollar-sign notation
#' et(nhanes$country)
et<-function(data_frame,variable_name){

  # define the table
  if(is.data.frame(data_frame)){
    variable_string<-deparse(substitute(variable_name))
    tt<-table(data_frame[,variable_string],useNA='always')
  } else {
    tt<-table(data_frame,useNA='always')
    variable_string<-gsub('^.+\\$','',deparse(substitute(data_frame)))
  }

  # put table in a data frame
  tt<-data.frame(value=names(tt),n=as.numeric(tt))

  # rename first column
  names(tt)[1]<-variable_string

  # output table
  tt

}

---
title: 'An introduction to *baseverse*'
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{An introduction to baseverse}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

## Overview

*baseverse* is intended to be a relatively minimal suite of packages, supporting the use of base R with native piping. 

Several functions are wrapper functions for existing base-R functions, adding support for native piping:

- `p_cor()`: a wrapper for `cor()`
- `p_glm()`: a wrapper for `glm()`
- `p_lm()`: a wrapper for `lm()`
- `p_t.test()`: a wrapper for `t.test()`
- `p_table()`: a wrapper for `table()`
- `p_wilcox.test()`: a wrapper for `wilcox.test()`

Other functions are wrapper functions for existing base-R features:

- `bang()`: is a wrapper for `!`, and is similar to `not()` from *magrittr*
- `bracket()`: is a wrapper for `[]`
- `dollar()`: is a wrapper for `$`, and is similar to `pull()` from *dplyr*

Other functions mimic tidyverse functions:

- `base_match()`: mimics `case_match()`, but returns a factor and respects the user's desired order of groups
- `base_when()`: mimics `case_when()`, but returns a factor and respects the user's desired order of groups
- `et()`: mimics `count()`

## Loading the package

Load the package:

```{r}
library(baseverse)
```

## Load the data

This vignette will draw from the built-in `nhanes` data:

```{r}
data(nhanes)
```

## Country of birth

Table the `dmdborn4` variable:

```{r}
nhanes |> p_table(dmdborn4)
```

Create a new, labelled version of `dmdborn4`:

```{r}
nhanes<-nhanes |> transform(
  country=base_match(dmdborn4,'USA'=1,'Other'=2)
)
```

Table the new variable using `p_table()`:

```{r}
nhanes |> p_table(country)
```

Or, table the new variable using `et()`:

```{r}
nhanes |> et(country)
```

Notice that the `USA` group is listed first. This is, deliberately, [hugely different behavior](https://github.com/yea-hung/baseverse#motivation) from `case_match()`. 

## Total cholesterol

Summarize the `lbxtc` variable:

```{r}
nhanes$lbxtc |> summary()
```

Or, using `dollar()`:


```{r}
nhanes |> dollar(lbxtc) |> summary()
```

Create a categorical variable for total cholesterol:

```{r}
nhanes<-nhanes |>
  transform(
    cholesterol=base_when(
      'Desirable' = (lbxtc<200),
      'Borderline high' = (lbxtc>=200)&(lbxtc<240),
      'High' = (lbxtc>=240)
    )
  )
```

Table the new variable using `p_table()`:

```{r}
nhanes |> p_table(cholesterol)
```

Or, table the new variable using `et()`:

```{r}
nhanes |> et(cholesterol)
```

Notice that the `Desirable` group is listed first. This is, deliberately, [hugely different behavior](https://github.com/yea-hung/baseverse#motivation) from `case_when()`. 

## Linear regression

Fit a linear model for systolic blood pressure (`bpxosy1`):

```{r}
model_1<-nhanes |> 
  p_lm(bpxosy1~ridageyr+country+lbxtc) 
```

Summarize the model:

```{r}
model_1 |>
  summary()
```

Obtain 95% confidence intervals for the coefficients:

```{r}
model_1 |>
  confint()
```

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/p_lm.r
\name{p_lm}
\alias{p_lm}
\title{Fits linear models, with support for piping}
\usage{
p_lm(data, formula, ...)
}
\arguments{
\item{data}{the data}

\item{formula}{the formula}

\item{...}{additional arguments passed to \code{\link[stats:lm]{stats::lm()}}.}
}
\value{
an \code{lm} object
}
\description{
A wrapper function for \code{lm()}, with the \code{data} argument listed first to support native piping.
}
\examples{
# load the data
data(nhanes)

# define country
nhanes<-nhanes |> transform(
  country=base_match(dmdborn4,'USA'=1,'Other'=2)
)

# fit a model
my_model<-nhanes |> p_lm(bpxosy1~country)

# obtain model details
my_model |> summary()

# obtain confidence interval
my_model |> confint()
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bracket.r
\name{bracket}
\alias{bracket}
\title{Subsets a data using bracket notation}
\usage{
bracket(data_object, index)
}
\arguments{
\item{data_object}{a data object}

\item{index}{a character, logical, or numeric vector}
}
\value{
a subset of the data
}
\description{
A wrapper function for bracket notation. The function only allows one index; for two-dimensional objects, the index is used on the columns.
}
\examples{
# load package
data(nhanes)

# look at the first few values of dmdborn4
nhanes |> bracket('dmdborn4') |> head()
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/p_table.r
\name{p_table}
\alias{p_table}
\title{Tables variables, with support for piping}
\usage{
p_table(data, x, y = NULL, ...)
}
\arguments{
\item{data}{the data}

\item{x}{one variable}

\item{y}{another variable}

\item{...}{additional arguments passed to \code{\link[=table]{table()}}.}
}
\value{
a \code{table} object
}
\description{
A wrapper function for \code{table()}, with support for piping.
}
\examples{
# load the data
data(nhanes)

# define smoking
nhanes<-nhanes |> transform(
  smoking=base_match(smq020,'No'=2,'History of smoking'=1)
)

# define asthma
nhanes<-nhanes |> transform(
  asthma=base_match(mcq010,'Asthma'=1,'No'=2)
)

# table smoking
nhanes |> p_table(smoking)

# table smoking and asthma
nhanes |> p_table(smoking,asthma)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dollar.r
\name{dollar}
\alias{dollar}
\title{Selects a portion of a data object using dollar-sign selection}
\usage{
dollar(data_object, variable_name)
}
\arguments{
\item{data_object}{the data object}

\item{variable_name}{the variable name or element name}
}
\value{
a portion of the data object
}
\description{
A wrapper function for dollar-sign notation.
}
\examples{
# load data
data(nhanes)

# summarize lbxtc
nhanes |> dollar(lbxtc) |> summary()
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/base_match.r
\name{base_match}
\alias{base_match}
\title{Defines factors using value-label mapping}
\usage{
base_match(original_variable, ..., as_factor = TRUE, string_for_na = "")
}
\arguments{
\item{original_variable}{the original variable}

\item{...}{the codebook, specified as a named vector, with each element in \code{'label'=value} format, with the levels listed in the desired order}

\item{as_factor}{logical, controlling whether the function should return a factor}

\item{string_for_na}{string value that will be converted to NA}
}
\value{
a factor
}
\description{
A base-R approximation of \code{case_match()} from 'dplyr'. Unlike \code{case_match()}, \code{base_when()} returns a factor. The levels will be ordered according to the order included in \code{...} (see below).
}
\examples{
# load data
data(nhanes)

# define country
nhanes<-nhanes |> transform(
  country=base_match(dmdborn4,'USA'=1,'Other'=2)
)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/not.r
\name{not}
\alias{not}
\title{Uses the logical not}
\usage{
not(x)
}
\arguments{
\item{x}{a logical object}
}
\value{
a logical object
}
\description{
A wrapper function for \code{!}. This is the same thing as \code{bang()}.
}
\examples{
# load the data
data(nhanes)

# check whether values of smq020 are not missing
nhanes$smq020 |> is.na() |> not()

# check whether values of smq020 are not missing
nhanes |> dollar(smq020) |> is.na() |> not()
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/p_glm.r
\name{p_glm}
\alias{p_glm}
\title{Fits generalized linear models, with support for piping}
\usage{
p_glm(data, formula, ...)
}
\arguments{
\item{data}{the data}

\item{formula}{the formula}

\item{...}{additional arguments passed to \code{\link[stats:glm]{stats::glm()}}.}
}
\value{
a \code{glm} object
}
\description{
A wrapper function for \code{glm()}, with the \code{data} argument listed first to support piping.
}
\examples{
# load the data
data(nhanes)

# define asthma
nhanes<-nhanes |> transform(
  asthma=base_match(mcq010,'No'=2,'History of asthma'=1)
)

# define smoking
nhanes<-nhanes |> transform(
  smoking=base_match(smq020,'No'=2,'History of smoking'=1)
)

# fit a model
my_model<-nhanes |> p_glm(asthma~smoking,family=binomial(link='logit'))

# obtain model details
my_model |> summary()

# obtain confidence interval
my_model |> confint() |> exp()
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bang.r
\name{bang}
\alias{bang}
\title{Uses the logical not}
\usage{
bang(x)
}
\arguments{
\item{x}{a logical object}
}
\value{
a logical object
}
\description{
A wrapper function for \code{!}.
}
\examples{
# load the data
data(nhanes)

# check whether values of smq020 are not missing
nhanes$smq020 |> is.na() |> bang()

# check whether values of smq020 are not missing
nhanes |> dollar(smq020) |> is.na() |> bang()
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/p_wilcox.test.r
\name{p_wilcox.test}
\alias{p_wilcox.test}
\title{Conducts Wilcoxon rank-sum tests, with support for piping}
\usage{
p_wilcox.test(data, x = NULL, y = NULL, formula = NULL, ...)
}
\arguments{
\item{data}{the data}

\item{x}{one of two variables}

\item{y}{one of two variables}

\item{formula}{a formula}

\item{...}{additional arguments passed to \code{\link[stats:wilcox.test]{stats::wilcox.test()}}.}
}
\value{
an \code{htest} object
}
\description{
A wrapper function for \code{wilcox.test()}, with the \code{data} argument listed first to support piping.
}
\examples{
# load the data
data(nhanes)

# define smoking
nhanes<-nhanes |> transform(
  smoking=base_match(smq020,'No'=2,'History of smoking'=1)
)

# conduct a one-sample wilcoxon test
nhanes |> p_wilcox.test(bpxosy1)

# conduct a two-sample wilcoxon test, using formula notation
nhanes |> p_wilcox.test(bpxosy1~smoking)

# conduct a two-sample wilcoxon test, using formula notation
nhanes |> p_wilcox.test(formula=bpxosy1~smoking)

# conduct a paired wilcoxon test, using x and y
nhanes |> p_wilcox.test(bpxosy1,bpxosy2,paired=TRUE)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/p_cor.r
\name{p_cor}
\alias{p_cor}
\title{Finds correlation coefficients, with support for piping}
\usage{
p_cor(data, x, y, ...)
}
\arguments{
\item{data}{the data}

\item{x}{one of the two variables}

\item{y}{one of the two variables}

\item{...}{additional arguments passed to \code{\link[stats:cor]{stats::cor()}}.}
}
\value{
a numeric object
}
\description{
A wrapper function for \code{cor()}, with support for piping.
}
\examples{
# load the data
data(nhanes)

# get correlation coefficient for systolic and diastolic
nhanes |> p_cor(bpxosy1,bpxodi1,use='complete.obs')
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/et.r
\name{et}
\alias{et}
\title{Tables variables}
\usage{
et(data_frame, variable_name)
}
\arguments{
\item{data_frame}{the data.frame}

\item{variable_name}{the variable name}
}
\value{
a data frame
}
\description{
Creates a table for a variable, mimicking \code{count()} from 'dplyr'. ET stands for exploratory table or easy table.
}
\examples{
# load data
data(nhanes)

# define country
nhanes<-nhanes |> transform(
  country=base_match(dmdborn4,'USA'=1,'Other'=2)
)

# examine variable, with native piping
nhanes |> et(country)

# examine variable, with dollar-sign notation
et(nhanes$country)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/base_when.r
\name{base_when}
\alias{base_when}
\title{Defines factors using logical objects}
\usage{
base_when(..., as_factor = TRUE, string_for_na = "")
}
\arguments{
\item{...}{conditions for defining the replacement values, specified as a named list, with each element in \code{'label'=logical_vector} format, with the levels listed in the desired order}

\item{as_factor}{logical, controlling whether the function should return a factor}

\item{string_for_na}{string value that will be converted to NA}
}
\value{
a factor
}
\description{
A base-R approximation of \code{case_when()} from 'dplyr'. Unlike \code{case_when()}, \code{base_when()} returns a factor. The levels will be ordered according to the order included in \code{...} (see below).
}
\examples{
# load data
data(nhanes)

# define cholesterol
nhanes<-nhanes |>
  transform(
    cholesterol=base_when(
      'Desirable' = (lbxtc<200),
      'Borderline high' = (lbxtc>=200)&(lbxtc<240),
      'High' = (lbxtc>=240)
    )
  )
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nhanes.r
\docType{data}
\name{nhanes}
\alias{nhanes}
\title{National Health and Nutrition Examination Survey data}
\format{
\subsection{\code{nhanes}}{

A data frame with 8,153 rows and 3 columns:
\describe{
\item{seqn}{a unique identifier}
\item{riagendr}{gender}
\item{ridageyr}{age}
\item{dmqmiliz}{military status}
\item{dmdborn4}{country of birth}
\item{lbxtc}{total cholesterol}
\item{bpxosy1}{systolic blood pressure}
\item{bpxosy2}{systolic blood pressure}
\item{bpxodi1}{diastolic blood pressure}
\item{bpxodi2}{diastolic blood pressure}
\item{mcq010}{asthma}
\item{smq020}{smoking status}
}
}
}
\source{
\url{https://wwwn.cdc.gov/nchs/nhanes/continuousnhanes/default.aspx?Cycle=2021-2023}
}
\usage{
nhanes
}
\description{
A subset of data from the National Health and Nutrition Examination Survey
}
\keyword{datasets}
